@@ -94,8 +94,7 @@ numerous times. There is also a first lookup function for names.
 =head2 Indexing
 
 Using a naive in-memory representation can be quite slow if you map gets big and the retrieval more
-complex. To improve the performance instances of L<TM::Index::*> can be associated with the
-map.
+complex. To improve the performance instances of L<TM::Index> can be associated with the map.
 
 =head2 TMDM
 
